==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QVBoxPlotModelMapper_shell.h <==
#ifndef QVBOXPLOTMODELMAPPER_SHELL_H
#define QVBOXPLOTMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qvboxplotmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QVBoxPlotModelMapper_shell : public QVBoxPlotModelMapper, public QtJambiShellInterface
{
public:
    QVBoxPlotModelMapper_shell(QObject* parent0 = nullptr);
    ~QVBoxPlotModelMapper_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QVBoxPlotModelMapper_mshell;
    friend class QVBoxPlotModelMapper_oshell;
};


class QVBoxPlotModelMapper_mshell : public QVBoxPlotModelMapper_shell
{
public:
    using QVBoxPlotModelMapper_shell::QVBoxPlotModelMapper_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QVBoxPlotModelMapper_oshell : public QVBoxPlotModelMapper_mshell
{
public:
    using QVBoxPlotModelMapper_mshell::QVBoxPlotModelMapper_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVBoxPlotModelMapper_access : public QVBoxPlotModelMapper
{
};

#endif // QVBOXPLOTMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiCharts/QVBoxPlotModelMapper_shell.h <==
#ifndef QVBOXPLOTMODELMAPPER_SHELL_H
#define QVBOXPLOTMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qvboxplotmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QVBoxPlotModelMapper_shell : public QVBoxPlotModelMapper, public QtJambiShellInterface
{
public:
    QVBoxPlotModelMapper_shell(QObject* parent0 = nullptr);
    ~QVBoxPlotModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVBoxPlotModelMapper_access : public QVBoxPlotModelMapper
{
};

#endif // QVBOXPLOTMODELMAPPER_SHELL_H
